@@ -14,7 +14,10 @@ sub analyse {
     my $class=shift;
     my $me=shift;
     
-    my $files=$me->d->{files_array};
+    my @files=@{$me->d->{files_array}};
+    if (my $ignore = $me->d->{ignored_files_array}) {
+        push @files, @$ignore;
+    }
     my $distdir=$me->distdir;
     my $manifest_file=catfile($distdir,'MANIFEST');
 
@@ -33,7 +36,7 @@ sub analyse {
         close $fh;
 
         @manifest=sort @manifest;
-        my @files=sort @$files;
+        my @files=sort @files;
 
         my $diff=Array::Diff->diff(\@manifest,\@files);
         if ($diff->count == 0) {
